@@ -8,8 +8,8 @@
 #ifndef KCOLORSCHEME_H
 #define KCOLORSCHEME_H
 
-#include <kconfigwidgets_export.h>
 #include <KSharedConfig>
+#include <kconfigwidgets_export.h>
 
 #include <QExplicitlySharedDataPointer>
 
@@ -55,7 +55,6 @@ class KColorSchemePrivate;
 class KCONFIGWIDGETS_EXPORT KColorScheme
 {
 public:
-
     /**
      * This enumeration describes the color set for which a color is being
      * selected.
@@ -112,7 +111,7 @@ public:
          */
         Complementary,
         /**
-         * Colors for header areas that thould be used both by the top toolbar and the titlebar titlebar.
+         * Colors for header areas that should be used both by the top toolbar and the titlebar.
          * @since 5.69
          */
         Header,
@@ -121,7 +120,7 @@ public:
          * Note: don't use this
          * @since 5.65
          */
-        NColorSets
+        NColorSets,
     };
 
     /**
@@ -181,14 +180,14 @@ public:
          */
         NeutralBackground,
         /**
-         * Eigth color; for example, success messages, trusted content.
+         * Eighth color; for example, success messages, trusted content.
          */
         PositiveBackground,
         /**
          * Number of background roles.
          * @since 5.65
          */
-        NBackgroundRoles
+        NBackgroundRoles,
     };
 
     /**
@@ -248,7 +247,7 @@ public:
          */
         NeutralText,
         /**
-         * Eigth color; for example, additions, success messages, trusted
+         * Eighth color; for example, additions, success messages, trusted
          * content.
          */
         PositiveText,
@@ -256,7 +255,7 @@ public:
          * Number of foreground roles.
          * @since 5.65
          */
-        NForegroundRoles
+        NForegroundRoles,
     };
 
     /**
@@ -282,7 +281,7 @@ public:
          * Number of decoration roles.
          * @since 5.65
          */
-        NDecorationRoles
+        NDecorationRoles,
     };
 
     /**
@@ -320,7 +319,7 @@ public:
          * Number of shade roles.
          * @since 5.65
          */
-        NShadeRoles
+        NShadeRoles,
     };
 
     /** Construct a copy of another KColorScheme. */
@@ -421,8 +420,7 @@ public:
      *
      * @see KColorUtils::shade
      */
-    static QColor shade(const QColor &, ShadeRole,
-                        qreal contrast, qreal chromaAdjust = 0.0);
+    static QColor shade(const QColor &, ShadeRole, qreal contrast, qreal chromaAdjust = 0.0);
 
     /**
      * Adjust a QPalette by replacing the specified QPalette::ColorRole with
@@ -466,6 +464,19 @@ public:
      */
     static QPalette createApplicationPalette(const KSharedConfigPtr &config);
 
+    /**
+     * Used to check if the color scheme has a given set.
+     *
+     * @param config KConfig from which to load the colors
+     *
+     * @param set The color set to check for.
+     *
+     * @returns whether the color scheme has a given color set
+     *
+     * @since 5.75
+     */
+    static bool isColorSetSupported(const KSharedConfigPtr &config, KColorScheme::ColorSet set);
+
 private:
     QExplicitlySharedDataPointer<KColorSchemePrivate> d;
 };
@@ -511,27 +522,21 @@ public:
      * If null, the application's color scheme is used (either the system
      * default, or one set by KColorSchemeManager).
      */
-    explicit KStatefulBrush(KColorScheme::ColorSet,
-                            KColorScheme::ForegroundRole,
-                            KSharedConfigPtr = KSharedConfigPtr());
+    explicit KStatefulBrush(KColorScheme::ColorSet, KColorScheme::ForegroundRole, KSharedConfigPtr = KSharedConfigPtr());
 
     /**
      * Construct a stateful brush from given color set and background role,
      * using the colors from the given KConfig (if null, the application's
      * colors are used).
      */
-    explicit KStatefulBrush(KColorScheme::ColorSet,
-                            KColorScheme::BackgroundRole,
-                            KSharedConfigPtr = KSharedConfigPtr());
+    explicit KStatefulBrush(KColorScheme::ColorSet, KColorScheme::BackgroundRole, KSharedConfigPtr = KSharedConfigPtr());
 
     /**
      * Construct a stateful brush from given color set and decoration role,
      * using the colors from the given KConfig (if null, the application's
      * colors are used).
      */
-    explicit KStatefulBrush(KColorScheme::ColorSet,
-                            KColorScheme::DecorationRole,
-                            KSharedConfigPtr = KSharedConfigPtr());
+    explicit KStatefulBrush(KColorScheme::ColorSet, KColorScheme::DecorationRole, KSharedConfigPtr = KSharedConfigPtr());
 
     /**
      * Construct a stateful background brush from a specified QBrush (or
@@ -555,8 +560,7 @@ public:
      * KColorScheme::NormalBackground role and QPalette::Active state for this
      * foreground/decoration color.
      */
-    explicit KStatefulBrush(const QBrush &, const QBrush &background,
-                            KSharedConfigPtr = KSharedConfigPtr());
+    explicit KStatefulBrush(const QBrush &, const QBrush &background, KSharedConfigPtr = KSharedConfigPtr());
 
     /** Construct a copy of another KStatefulBrush. */
     KStatefulBrush(const KStatefulBrush &);
@@ -582,6 +586,7 @@ public:
      */
     QBrush brush(const QPalette &) const;
 
+#if KCONFIGWIDGETS_ENABLE_DEPRECATED_SINCE(5, 84)
     /**
      * Retrieve the brush, using a QWidget pointer to determine the correct
      * state. Use when you have a pointer to the widget that you are painting.
@@ -589,8 +594,13 @@ public:
      *
      * @note If you pass an invalid widget, you will get a default brush (i.e.
      * <tt>QBrush()</tt>).
+     * @deprecated Since 5.84, use @ref brush(const QPalette &) instead.
+     * A typical replacement would be <tt>brush(widget->palette())</tt>
+     * (in case @c widget cannot be @c null in this context).
      */
+    KCONFIGWIDGETS_DEPRECATED_VERSION(5, 84, "Use KStatefulBrush::brush(const QPalette&) instead")
     QBrush brush(const QWidget *) const;
+#endif
 
 private:
     class KStatefulBrushPrivate *d;
